SIMDE_TEST_DECLARE_SUITE(mmx)
SIMDE_TEST_DECLARE_SUITE(sse)
SIMDE_TEST_DECLARE_SUITE(sse2)
SIMDE_TEST_DECLARE_SUITE(sse3)
SIMDE_TEST_DECLARE_SUITE(ssse3)
SIMDE_TEST_DECLARE_SUITE(sse4_1)
SIMDE_TEST_DECLARE_SUITE(sse4_2)
SIMDE_TEST_DECLARE_SUITE(avx)
SIMDE_TEST_DECLARE_SUITE(avx2)
SIMDE_TEST_DECLARE_SUITE(fma)
SIMDE_TEST_DECLARE_SUITE(gfni)
SIMDE_TEST_DECLARE_SUITE(clmul)
SIMDE_TEST_DECLARE_SUITE(svml)
SIMDE_TEST_DECLARE_SUITE(xop)
