SIMDE_TEST_DECLARE_SUITE(2intersect)
SIMDE_TEST_DECLARE_SUITE(abs)
SIMDE_TEST_DECLARE_SUITE(add)
SIMDE_TEST_DECLARE_SUITE(adds)
SIMDE_TEST_DECLARE_SUITE(and)
SIMDE_TEST_DECLARE_SUITE(andnot)
SIMDE_TEST_DECLARE_SUITE(avg)
SIMDE_TEST_DECLARE_SUITE(blend)
SIMDE_TEST_DECLARE_SUITE(broadcast)
SIMDE_TEST_DECLARE_SUITE(cast)
SIMDE_TEST_DECLARE_SUITE(cmpeq)
SIMDE_TEST_DECLARE_SUITE(cmpge)
SIMDE_TEST_DECLARE_SUITE(cmpgt)
SIMDE_TEST_DECLARE_SUITE(cmp)
SIMDE_TEST_DECLARE_SUITE(cmple)
SIMDE_TEST_DECLARE_SUITE(cmplt)
SIMDE_TEST_DECLARE_SUITE(copysign)
SIMDE_TEST_DECLARE_SUITE(cvt)
SIMDE_TEST_DECLARE_SUITE(cvts)
SIMDE_TEST_DECLARE_SUITE(div)
SIMDE_TEST_DECLARE_SUITE(extract)
SIMDE_TEST_DECLARE_SUITE(fmadd)
SIMDE_TEST_DECLARE_SUITE(fmsub)
SIMDE_TEST_DECLARE_SUITE(fnmadd)
SIMDE_TEST_DECLARE_SUITE(fnmsub)
SIMDE_TEST_DECLARE_SUITE(insert)
SIMDE_TEST_DECLARE_SUITE(kshift)
SIMDE_TEST_DECLARE_SUITE(load)
SIMDE_TEST_DECLARE_SUITE(loadu)
SIMDE_TEST_DECLARE_SUITE(lzcnt)
SIMDE_TEST_DECLARE_SUITE(madd)
SIMDE_TEST_DECLARE_SUITE(maddubs)
SIMDE_TEST_DECLARE_SUITE(max)
SIMDE_TEST_DECLARE_SUITE(min)
SIMDE_TEST_DECLARE_SUITE(mov)
SIMDE_TEST_DECLARE_SUITE(mov_mask)
SIMDE_TEST_DECLARE_SUITE(movm)
SIMDE_TEST_DECLARE_SUITE(mul)
SIMDE_TEST_DECLARE_SUITE(mulhi)
SIMDE_TEST_DECLARE_SUITE(mulhrs)
SIMDE_TEST_DECLARE_SUITE(mullo)
SIMDE_TEST_DECLARE_SUITE(negate)
SIMDE_TEST_DECLARE_SUITE(or)
SIMDE_TEST_DECLARE_SUITE(packs)
SIMDE_TEST_DECLARE_SUITE(packus)
SIMDE_TEST_DECLARE_SUITE(permutex2var)
SIMDE_TEST_DECLARE_SUITE(permutexvar)
SIMDE_TEST_DECLARE_SUITE(sad)
SIMDE_TEST_DECLARE_SUITE(set1)
SIMDE_TEST_DECLARE_SUITE(set4)
SIMDE_TEST_DECLARE_SUITE(set)
SIMDE_TEST_DECLARE_SUITE(setone)
SIMDE_TEST_DECLARE_SUITE(setr4)
SIMDE_TEST_DECLARE_SUITE(setr)
SIMDE_TEST_DECLARE_SUITE(setzero)
SIMDE_TEST_DECLARE_SUITE(shuffle)
SIMDE_TEST_DECLARE_SUITE(sll)
SIMDE_TEST_DECLARE_SUITE(slli)
SIMDE_TEST_DECLARE_SUITE(sllv)
SIMDE_TEST_DECLARE_SUITE(sqrt)
SIMDE_TEST_DECLARE_SUITE(sra)
SIMDE_TEST_DECLARE_SUITE(srai)
SIMDE_TEST_DECLARE_SUITE(srav)
SIMDE_TEST_DECLARE_SUITE(srl)
SIMDE_TEST_DECLARE_SUITE(srli)
SIMDE_TEST_DECLARE_SUITE(srlv)
SIMDE_TEST_DECLARE_SUITE(store)
SIMDE_TEST_DECLARE_SUITE(storeu)
SIMDE_TEST_DECLARE_SUITE(sub)
SIMDE_TEST_DECLARE_SUITE(subs)
SIMDE_TEST_DECLARE_SUITE(test)
SIMDE_TEST_DECLARE_SUITE(unpackhi)
SIMDE_TEST_DECLARE_SUITE(unpacklo)
SIMDE_TEST_DECLARE_SUITE(xor)
SIMDE_TEST_DECLARE_SUITE(xorsign)
